summaryrefslogtreecommitdiff
path: root/src/MDD.cpp
diff options
context:
space:
mode:
authorJohn Hurst <jhurst@cinecert.com>2019-12-30 14:03:32 -0800
committerGitHub <noreply@github.com>2019-12-30 14:03:32 -0800
commit39d533e10e9f5248c557caa0777c8c10ed5d737c (patch)
tree6e03793692f45418ea89c55edcb95ce89d9aad5b /src/MDD.cpp
parent5dd260660cfa14ece62365139962dfb4cbbafb10 (diff)
parenta67f55782d4758355190fe3f14ac6159b9d79e1e (diff)
Merge branch 'master' into htj2c
Diffstat (limited to 'src/MDD.cpp')
-rw-r--r--src/MDD.cpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/MDD.cpp b/src/MDD.cpp
index 71aefca..06d0fde 100644
--- a/src/MDD.cpp
+++ b/src/MDD.cpp
@@ -1156,12 +1156,12 @@ static const ASDCP::MDDEntry s_MDD_Table[] = {
{0}, false, "DBOXMotionCodeSecondaryStream" },
// 379-2, Sec. 7: Encoders that conform to this specification shall add a
// ContainerConstraintSubDescriptor to the GenericDescriptor::SubDescriptors
// property of the top-most File Descriptor that describes the essence
// container.
{ { 0x06, 0x0e, 0x2b, 0x34, 0x02, 0x53, 0x01, 0x01, // 373
0x0d, 0x01, 0x01, 0x01, 0x01, 0x01, 0x67, 0x00 },
- {0}, false, "ContainerConstraintSubDescriptor" },
+ {0}, false, "ContainerConstraintsSubDescriptor" },
// protype for high dynamic range, values recorded in Dolby registry
{ { 0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x05, // 374
@@ -1627,7 +1627,9 @@ static const ASDCP::MDDEntry s_MDD_Table[] = {
{ { 0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x0D,
0x04, 0x01, 0x02, 0x02, 0x03, 0x01, 0x08, 0x01 },
{0}, false, "HTJ2KPictureCodingSchemeGeneric" }, // 524
-
+ { { 0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x0d, // 525
+ 0x0d, 0x0f, 0x03, 0x02, 0x01, 0x01, 0x00, 0x00 },
+ {0}, false, "AudioChannelSLVS" },
{ {0}, {0}, false, 0 },
};
@@ -1156,12 +1156,12 @@ static const ASDCP::MDDEntry s_MDD_Table[] = {
{0}, false, "DBOXMotionCodeSecondaryStream" },
// 379-2, Sec. 7: Encoders that conform to this specification shall add a
- // ContainerConstraintSubDescriptor to the GenericDescriptor::SubDescriptors
+ // ContainerConstraintsSubDescriptor to the GenericDescriptor::SubDescriptors
// property of the top-most File Descriptor that describes the essence
// container.